function ScenePlayer(options) {
	this.options = options;
}

/*
* Stream types
*/
StreamTypes = {live:0, shifted:1, archive:2, vod:3, radio:4, arcPlus: 5};

/*
* Service statuses
*/
ServiceStatuses = {na:0, available:1, previewAvailable:2, enabled:3};

ScenePlayer.prototype.initialize = function () {
	Logger.write("ScenePlayer.initialize()", "Player");
    ScenePlayer.time = 5000;
    ScenePlayer.setHelpBar();
    ScenePlayer.timeoutForJump = 4000;
    ScenePlayer.jumpValue = 60000;
	ScenePlayer.errorCount = 0;
}

ScenePlayer.firstTimeStart = true;
ScenePlayer.autoPlay = true;

ScenePlayer.setHelpBar = function () {
	var keys = {
		'red':Resources.getResources().LabelSettings
	};
	if (ScenePlayer.streamType != StreamTypes.radio) {
		keys['green'] = Resources.getResources().Ratio;
	}
	if (ScenePlayer.sender == "Series" || ScenePlayer.sender == "ProgramEpisodes") {
		if (ScenePlayer.autoPlay) {
			keys['yellow'] = Resources.getResources().PlayerAutoPlayOn;
		} else {
			keys['yellow'] = Resources.getResources().PlayerAutoPlayOff;
		}
	}
	keys['blue'] = Resources.getResources().Menu;
	keys['stop'] = Resources.getResources().Stop;
	keys['play'] = Resources.getResources().Play;
	if (ScenePlayer.streamType != StreamTypes.live && ScenePlayer.streamType != StreamTypes.shifted && ScenePlayer.streamType != StreamTypes.radio) {
		keys['rew'] = '';
		keys['ff'] = Resources.getResources().Jump;
	}
	keys['return'] = Resources.getResources().Back;
	$('#helpKeysPlayer').sfKeyHelp(keys);
	
	$("#radioInfo .buffering").html(Resources.getResources().Buffering);
}

/*------------------Player events-----------------*/

ScenePlayer.isNotEnoughErrors = function () {
	if (AppContext.CurrentScene === "LiveTv") {
		Logger.write("Not enough errors", "Player", true);
		return ScenePlayer.errorCount < 3;
	}
	
	Logger.write("Enough errors", "Player", true);
	return false;
}

ScenePlayer.onPlayerStreamReady = function () {
    Logger.write("[player] stream ready", "Player");
	if (ScenePlayer.isStopped) {
		Logger.write("[player] stream stopped", "Player");
		return;
	}
	
    try
    {
		ScenePlayer.errorCount = 0;
        $('#svecVideo2_50Z0').sfVideo2("setTotalTime");
        ScenePlayer.showControls();
        ScenePlayer.isPlaying = true;
		
		if (ScenePlayer.sender != "Radio") {
			pluginAPI.setOffScreenSaver();
		}
        
        if (ScenePlayer.streamType == StreamTypes.radio)
        {
			$("#svecVideo2_50Z0").sfVideo2("clearScreen");
			var rect = {
				top: 0, left: 0,
				width: 0, height: 0
			};
			$("#svecVideo2_50Z0").sfVideo2("setDisplayArea", rect);
            return;
        }
        
		//if (!ScenePlayer.ar) {
			ScenePlayer.setAspectRatio(ScenePlayer.aspectRatio);
		//}
        
        Logger.write("Content duration=" + $('#svecVideo2_50Z0').sfVideoGetContentDuration(), "Player"); 
        if (ScenePlayer.serviceStatus == ServiceStatuses.previewAvailable)
        {
            SceneErrorPopUp.backTo ="Player";
            ErrorHandler.HandleError(Resources.getResources().YouAreNotSubscribedToThisService, "ServicePlayer");
        }
    }
    catch(ex)
    {
          ScenePlayer.stopAndReturn();
          ErrorHandler.HandleError(ex,"Player");
    }
}

ScenePlayer.onBufferingStart = function () {
	if (ScenePlayer.sender == "Radio") {
		$("#radioInfo .buffering").show();
	} else {
		$("#playerLoadingHolder").css({'visibility' : 'visible'});
		$("#imgPlayerLoading").css({'visibility' : 'visible'});
		$("#playerLoadingHolder").css({'z-index' : '1234'});
		$("#imgPlayerLoading").css({'z-index' : '1234'});
		$("#imgPlayerLoading").sfLoading('show');
	}
}

ScenePlayer.onBufferingComplete = function () {
	if (ScenePlayer.sender == "Radio") {
		$("#radioInfo .buffering").hide();
	} else {
		$("#imgPlayerLoading").sfLoading('hide');
		$("#loadingObject").sfLoading('hide');
	}
}

ScenePlayer.onStreamCompleted = function () {
	Logger.write("Stream completed", "Player");
    
	Logger.write("Time: " + $('#svecVideo2_50Z0').sfVideo2("getPlayedTime") + "/" + $('#svecVideo2_50Z0').sfVideo2("getTotalTime"), "Player", true);
    try {
		ScenePlayer.stop();
		var isUnexpected = $('#svecVideo2_50Z0').sfVideo2("getUnexpectedRenderComplete");
		if (isUnexpected) {
			var timeToResume = $('#svecVideo2_50Z0').sfVideo2("getPlayedTime") / 1000;
			$('#svecVideo2_50Z0').sfVideo2("resume", timeToResume);
			return;
		}
		
		if (ASXLoader.hasNext) {
			 ScenePlayer.setUrlCallback();
		} else if ((ScenePlayer.sender == "Series" || ScenePlayer.sender == "ProgramEpisodes") && ScenePlayer.autoPlay && ScenePlayer.episodePicker) {
			Logger.write("Pick next episode is possible", "Player", true);
			var result = ScenePlayer.sender == "Series" ? ScenePlayer.episodePicker.setNext() : ScenePlayer.episodePicker.setPrev();
			if (!result) {
				ScenePlayer.handleReturn();
			}
		} else {
			ScenePlayer.handleReturn();
		}
	} catch (ex) {
		ScenePlayer.stopAndReturn();
		ErrorHandler.HandleError(ex,"Player");
	}
}

ScenePlayer.onError = function (error) {
	Logger.write("Error #" + error.code + ": " + error.message, "Player");
	switch (error.code) {
		case 8:
			ScenePlayer.stopAndReturn();
			break;
		case 19:
			//network error
			break;
	}
}


/*--------------end Player events---------------*/

/*
*Shows controls and helpbar, sets timeout to hide
*/
ScenePlayer.showControls = function () {
	if (!ScenePlayer.isFocused) {
		return;
	}
    if (typeof(ScenePlayer.timeout) != "undefined") {
            clearTimeout(ScenePlayer.timeout);
    }
    ScenePlayer.timeout = setTimeout(ScenePlayer.hideControls, ScenePlayer.time);
    $('#svecVideo2_controller_YQ4I').show();
    $('#helpKeysPlayer').show();
}

ScenePlayer.prototype.handleShow = function () {
	Logger.write("ScenePlayer.handleShow()", "Player");
	// this function will be called when the scene manager show this scene
}

/*
Sets name and url of video to play
*/
ScenePlayer.setContent = function(content, sender){
	Logger.write("ScenePlayer.setContent(" + content + ", " + sender + ")", "Player");
    var url = content.url;
	ScenePlayer.contentType = content.contentType;
	ScenePlayer.sender = sender;
    Logger.write("url="+url, "Player")
	Logger.write("playlist="+content.playlist, "Player");

    if  (ScenePlayer.isPlaying === true)
    {
		ScenePlayer.stopPlayer();
    }
	if (content.ar && content.ar.x && content.ar.y) { //aspect ratio provided by services
		ScenePlayer.ar = content.ar;
	} else {
		ScenePlayer.ar = null;
	}
	ScenePlayer.aspectRatio = ScenePlayer.aspectRatios.normal;

	ScenePlayer.onBufferingStart();
    ScenePlayer.contentDuration = content.duration || 0;
	Logger.write("Duration: " + content.duration, "Player", true);
    $("#radioInfo").hide();
	
	if (content.contentType == "LiveTV")
	{
		if (AppContext.ClientSettings.shiftTimeZoneName.indexOf("EU_RST") != -1)
		{
			ScenePlayer.streamType = StreamTypes.live;
		}
		else
		{
			ScenePlayer.streamType = StreamTypes.shifted;
		} 
	}
	else 
	{
		if (content.contentType == "Radio") {
			ScenePlayer.streamType = StreamTypes.radio;
			$("#radioInfo").show();
			$("#radioInfo .logo img").sfImage({'src': content.imageUrl});
		} else if (content.contentType == "VOD") {
			ScenePlayer.streamType = StreamTypes.vod;
		} else if (content.contentType == "DVR") {
			ScenePlayer.streamType = StreamTypes.archive;
		} else if (content.contentType == "ArcPlus") {
			ScenePlayer.streamType = StreamTypes.arcPlus;
		}
	}
	ScenePlayer.serviceStatus = Helpers.checkStatus(content.contentType);
	
    if (!url && content.playlist.indexOf("<ASX VERSION") > -1)
    {
		Logger.write("===== playing playlist", "Player");
		ASXLoader.parse(content.playlist);
		if (AppContext.CurrentScene == "Favorites")
		{
			ScenePlayer.archProgramPicker = null;
		}
		ScenePlayer.contentDuration = ASXLoader.getTotalDuration();
		$('#svecVideo2_50Z0').sfVideo2SetDuration(ScenePlayer.contentDuration);
		var asxUrl = ASXLoader.getNextUrl();
		ScenePlayer.playUrl(asxUrl);
    }
    else
    {       
		Logger.write("===== playing url", "Player");
		ASXLoader.hasNext = false;
		ASXLoader.hasPlayList = false;
		
		//$('#svecVideo2_50Z0').sfVideo2SetDuration(ScenePlayer.contentDuration);
		
		ScenePlayer.playUrl(url);
    }
    ScenePlayer.playingInfo = "begin";
	ScenePlayer.setHelpBar();
    Logger.write("[player] url to play="+url, "Player");
}

/*
Sets new url from ASX
*/
ScenePlayer.setUrlCallback = function(){
    if  (ScenePlayer.isPlaying == true) {
		ScenePlayer.stopPlayer();
    }
    var url = ASXLoader.getNextUrl();
    Logger.write("[player] url to play="+url, "Player");
    ScenePlayer.playUrl(url);
}


/*
Runs specified url on player
*/
ScenePlayer.playUrl = function(url){
	Logger.write("ScenePlayer.playUrl(" + url + ")", "Player");
    if (url == "")
    {
        Logger.write("[player] url not defined", "Player");
        ScenePlayer.stop();
        return;
    }    
	
	var startTime = ASXLoader.getCurrentStartTime();
            
    /*if (ScenePlayer.firstTimeStart)
    {
		Logger.write("Player first time start. ", "Player", true);
		
    } else {
		Logger.write("Player not first time start. ", "Player", true);
		$('#svecVideo2_50Z0').sfVideo2SetUrl(url);
		$('#svecVideo2_50Z0').sfVideo2("play");
	}*/
	if (!ScenePlayer.firstTimeStart && $('#svecVideo2_50Z0').sfVideo2("getStatus") != 3) {
		ScenePlayer.stop();
	}
	
	ScenePlayer.isStopped = false;
	var settings = Helpers.loadBuffers();
	var totalBuffer = parseInt(settings.totalBuffer)*1024;
	var pendingBuffer = parseInt(settings.pendingBuffer)*1024;
	var initialBuffer = parseInt(settings.initialBuffer)*1024;
	if (ScenePlayer.streamType == StreamTypes.radio) {
		totalBuffer /= 10;
		pendingBuffer /= 10;
		initialBuffer /= 10;
	}
	
	//Logger.write("Buffers:\nTotal: " + totalBuffer + "; Pending: " + pendingBuffer + "; Initial: " + initialBuffer + ";", "Player", true);
	playOptions = {
		totalBufferSize: totalBuffer,
		pendingBufferSize: pendingBuffer,
		initialBufferSize: initialBuffer
	};
	
	var options = {
		displayRect: {
			left: 0,
			top: 0,
			width: 960,
			height: 540
		},
		urlMedia: url,
		idVideo2_controller: "svecVideo2_controller_YQ4I",
		duration: ScenePlayer.contentDuration,
		jumpSeconds: '10',
		onPlayerStreamReady: ScenePlayer.onPlayerStreamReady,
		playOptions: playOptions
	};
	$("#svecVideo2_50Z0").sfVideo2(options);
	Logger.write("Video2 initialized", "Player", true);
	$('#svecVideo2_controller_YQ4I').sfVideo2_controller();
	Logger.write("Video2 controller initialized", "Player", true);
    ScenePlayer.onBufferingStart();
	if (ScenePlayer.ar) {
		ScenePlayer.setAspectRatio(ScenePlayer.aspectRatio);
	}
	
	$('#svecVideo2_controller_YQ4I').activateButtons();
	if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted || ScenePlayer.streamType == StreamTypes.radio) {
		$('#svecVideo2_controller_YQ4I').deactivateButton("pause");
		$('#svecVideo2_controller_YQ4I').deactivateButton("backward");
		$('#svecVideo2_controller_YQ4I').deactivateButton("forward");
	}
	Helpers.setBackgroundOpacity();
    ScenePlayer.firstTimeStart = false;
	var title = ""
    if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted)//remove shifted, it's for tests
    {    
        var currentChannel = ScenePlayer.channelPicker.getSettedChannel();
        Logger.write("currentChannel="+currentChannel, "Player");
		$('#svecVideo2_controller_YQ4I').setChannel(currentChannel);
    }
    else
    {
        $('#svecVideo2_controller_YQ4I').setChannel("");
    }
	
	$('#svecVideo2_controller_YQ4I').sfVideo2_controller("setFullScreen");
}

/*
Plays video
*/
ScenePlayer.play = function(){
	Helpers.setBackgroundOpacity();
	$("#svecVideo2_50Z0").sfVideo2("play");
	ScenePlayer.isStopped = false;
}

ScenePlayer.pause = function () {
	$("#svecVideo2_50Z0").sfVideo2("pause");
}

/*
Stops player and removes background opacity
*/
ScenePlayer.stop = function () {
	Logger.write("ScenePlayer.stop()", "Player", true);
    $("#imgPlayerLoading").sfLoading('hide');
    $("#loadingObject").sfLoading('hide');
    ScenePlayer.isPlaying = false;
	ScenePlayer.isStopped = true;
    Helpers.removeBackgroundOpacity();
    pluginAPI.setOnScreenSaver();
	$("#svecVideo2_50Z0").sfVideo2("stop");
}

/*
Stops player
*/
ScenePlayer.stopPlayer = function () {
    $("#imgPlayerLoading").sfLoading('hide');
    $("#loadingObject").sfLoading('hide');
    ScenePlayer.isPlaying = false;
}

/*
Hides player's controls
*/
ScenePlayer.hideControls = function(){
    if (ScenePlayer.streamType == StreamTypes.radio)
        return;

    $('#svecVideo2_controller_YQ4I').hide();
    $('#helpKeysPlayer').hide();
}

/*
Stops player and returns to previous scene
*/
ScenePlayer.stopAndReturn = function(){
    ScenePlayer.stop();
    ScenePlayer.handleReturn();
}

ScenePlayer.aspectRatios = {normal:0, stretch:1, zoom:2};
ScenePlayer.aspectRatio = ScenePlayer.aspectRatios.normal;

/*
* Changes aspect ratio
*/
ScenePlayer.setAspectRatio = function(aspectRatio){
        ScenePlayer.aspectRatio = aspectRatio;
		
		var resolution = $("#svecVideo2_50Z0").sfVideo2("getVideoResolution");
		if (!resolution || typeof resolution !== "string" || resolution.indexOf("|") < -1) {
			return;
		}
		var sizes = resolution.split('|');
        
        var oldwidth = parseInt(sizes[0]);
        var oldheight = parseInt(sizes[1]);
        
        Logger.write("[player] original width=" + oldwidth, "Player");
        Logger.write("[player] original height=" + oldheight, "Player");
        
        var height = MAX_HEIGHT_SCREEN;
        var width = MAX_WIDTH_SCREEN;
        
        var ar = ScenePlayer.ar ? ScenePlayer.ar.x / ScenePlayer.ar.y : oldwidth / oldheight;
        Logger.write("AR: " + ar, "Player", true);
        Logger.write("X:" + ScenePlayer.ar.x, "Player", true);
        Logger.write("Y:" + ScenePlayer.ar.y, "Player", true);
        Logger.write("16/9:" + 16/9, "Player", true);
        switch (aspectRatio)
        {
            case ScenePlayer.aspectRatios.normal:
				if (ar > (16 / 9)) {
					height = width / ar;
				} else if (ar < (16 / 9)) {
					width = height * ar;
				}
                break;    
            case ScenePlayer.aspectRatios.zoom:
				if (ar < (16 / 9)) {
					height = width / ar;
				} else if (ar > (16 / 9)) {
					width = height * ar;
				}
                break;
        }
            
        var y =  Math.ceil(MAX_HEIGHT_SCREEN/2 - height/2);
        var x =  Math.ceil(MAX_WIDTH_SCREEN/2 - width/2);
		width = Math.ceil(width);
		height = Math.ceil(height);
        Logger.write("[player] width=" + width, "Player");
        Logger.write("[player] height=" + height, "Player");
        Logger.write("[player] x=" + x, "Player");
        Logger.write("[player] y=" + y, "Player");
		
		rect = {
			left: x,
			top: y,
			width: width,
			height: height
		};
		$("#svecVideo2_50Z0").sfVideo2("setDisplayArea", rect);
}


/*
* Handles green button pressing
*/
ScenePlayer.handleGreenButton = function(){
    switch(ScenePlayer.aspectRatio){
            case ScenePlayer.aspectRatios.normal:
                ScenePlayer.setAspectRatio(ScenePlayer.aspectRatios.stretch);
                break;
            case ScenePlayer.aspectRatios.stretch:
                ScenePlayer.setAspectRatio(ScenePlayer.aspectRatios.normal);
                break;
            /*case ScenePlayer.aspectRatios.zoom:
                ScenePlayer.setAspectRatio(ScenePlayer.aspectRatios.normal);
                break;*/
    }
}

/*
Handles the press of a button return
*/
ScenePlayer.handleReturn = function(){
    //sf.scene.hide('Player');
	Logger.write("Current scene (handleReturn): " + AppContext.CurrentScene, "Player", true);
    sf.scene.show(AppContext.CurrentScene);
    sf.scene.focus(AppContext.CurrentScene);
    
    /*if ((ScenePlayer.isPlaying != true) && (!ScenePlayer.firstTimeStart))
        ScenePlayer.stop();*/
}

ScenePlayer.prototype.handleHide = function () {
	Logger.write("ScenePlayer.handleHide()", "Player");
	// this function will be called when the scene manager hide this scene  
}

ScenePlayer.prototype.handleFocus = function () {
	Logger.write("ScenePlayer.handleFocus()", "Player");
	// this function will be called when the scene manager focus this scene
    sf.scene.hide(AppContext.CurrentScene);
    ScenePlayer.setHelpBar();      
	Logger.write("Scene service status: " + ScenePlayer.serviceStatus, "Player", true);
    if  (ScenePlayer.serviceStatus < ServiceStatuses.previewAvailable)
    {
        ScenePlayer.stopAndReturn();
        ErrorHandler.HandleError(Resources.getResources().YouAreNotSubscribedToThisService, "ServicePlayer");
    }
	ScenePlayer.isStopped = false;
	Logger.write("Current scene (handleFocus): " + AppContext.CurrentScene, "Player", true);
	ScenePlayer.isFocused = true;
	ScenePlayer.showControls();
	if (ScenePlayer.sender != "Radio") {
		pluginAPI.setOffScreenSaver();
	}
}

ScenePlayer.prototype.handleBlur = function () {
	Logger.write("ScenePlayer.handleBlur()", "Player");
	// this function will be called when the scene manager move focus to another scene from this scene
	ScenePlayer.isFocused = false;
	ScenePlayer.hideControls();
}

/*
* Handles num button pressing
*/
ScenePlayer.handleNumPress = function(num){
    if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted) //remove shifted, it's for tests
    {
        ScenePlayer.channelPicker.numPressed(num);
        var currentChannel = ScenePlayer.channelPicker.getCurrentChannel();
        $('#svecVideo2_controller_YQ4I').setChannel(currentChannel);
    }
}

ScenePlayer.handleUpDown = function(){
    return  ScenePlayer.streamType == StreamTypes.archive && ScenePlayer.archProgramPicker != null;
}

ScenePlayer.handlePressUp = function(){
	Logger.write("ScenePlayer.handlePressUp()", "Player");
    if (ScenePlayer.handleUpDown())
    {
		Logger.write("Prev program in ArchTv", "Player");
        ScenePlayer.archProgramPicker.setPrev();
    }
    else if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted)//remove shifted, it's for tests
    {
		Logger.write("Prev LiveTv program", "Player");
        ScenePlayer.channelPicker.setPrev();
    } else if (ScenePlayer.streamType == StreamTypes.radio && SceneRadio.channelPicker) {
		Logger.write("Prev radiostation", "Player");
		SceneRadio.channelPicker.setPrev();
	}
}

ScenePlayer.handlePressDown = function(){
	Logger.write("ScenePlayer.handlePressDown()", "Player");
    if (ScenePlayer.handleUpDown()) 
    {
		Logger.write("Next program in ArchTv", "Player");
        ScenePlayer.archProgramPicker.setNext();
    }
    else if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted)//remove shifted, it's for tests
    {
		Logger.write("Next LiveTv program", "Player");
        ScenePlayer.channelPicker.setNext();
    } else if (ScenePlayer.streamType == StreamTypes.radio && SceneRadio.channelPicker) {
		Logger.write("Next radiostation", "Player");
		SceneRadio.channelPicker.setNext();
	}
}

ScenePlayer.handleChUp = function () {
	if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted) {
		ScenePlayer.channelPicker.setNext();
	}
}

ScenePlayer.handleChDown = function () {
	if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted) {
		ScenePlayer.channelPicker.setPrev();
	}
}

ScenePlayer.jump = {};
ScenePlayer.jump.value = 0;

ScenePlayer.handlePressJump = function(value){
	var status = $("svecVideo2_50Z0").sfVideo2("getStatus");
	/*if (status == 2) {
		return; 
	}*/
	
    ScenePlayer.jump.value += value;
    Logger.write("[Player] value to jump = " + ScenePlayer.jump.value, "Player");
    
    if (ScenePlayer.jumpPressed) {
		Logger.write("Jump pressed", "Player");
		var position = ScenePlayer.jump.time + ScenePlayer.jump.value;
		var duration = ScenePlayer.jump.duration;
		
		if (ASXLoader.hasPlayList) {
			var section = ASXLoader.getCurrentSection(position / 1000);
			if (section) {
				position -= section.start * 1000;
				duration = section.duration * 1000;
			}
		}
		
		var progress = position * 100 / duration;
		if (progress > 100) {
			progress = 100;
			if (!ASXLoader.hasPlayList) {
				ScenePlayer.jump.value = ScenePlayer.jump.duration - ScenePlayer.jump.time;
			}
		}
		
         $('#svecVideo2_controller_YQ4I').setProgress(progress);
         
         var totalTime = Helpers.intTimeToString(duration);
         var time = Helpers.intTimeToString(position);
         
         $('#svecVideo2_controller_YQ4I').setTime(time + "/" +totalTime);
         $('#svecVideo2_controller_YQ4I').changeButton((value > 0) ? "forward" : "backward");
    } else {
		Logger.write("Jump isn't pressed", "Player");
        $('#svecVideo2_50Z0').sfVideo2("pause");
        $('#svecVideo2_controller_YQ4I').changeButton((value > 0) ? "forward" : "backward");   
        
        ScenePlayer.jump.time = $('#svecVideo2_50Z0').sfVideoGetCurrentTime();  
        ScenePlayer.jump.duration = $('#svecVideo2_50Z0').sfVideoGetContentDuration(); 
		
		var position = ScenePlayer.jump.time + ScenePlayer.jump.value;
		var duration = ScenePlayer.jump.duration;
		
		if (ASXLoader.hasPlayList) {
			var section = ASXLoader.getCurrentSection(position / 1000);
			if (section) {
				position -= section.start * 1000;
				duration = section.duration * 1000;
			}
		}
        
        var progr = position * 100 / duration;
		if (progr > 100) {
			progr = 100;
		}
		
        $('#svecVideo2_controller_YQ4I').setProgress(progr);
        
        var totalTime = Helpers.intTimeToString(duration);
        var time = Helpers.intTimeToString(position);
        $('#svecVideo2_controller_YQ4I').setTime(time + "/" +totalTime);
        
        ScenePlayer.jumpPressed = true;
    }
	
	Logger.write("Clearing and setting timeout", "Player");
    if (ScenePlayer.jumpTimeout) {
        clearTimeout(ScenePlayer.jumpTimeout);
    }
    ScenePlayer.jumpTimeout = setTimeout(ScenePlayer.jump.cb, ScenePlayer.timeoutForJump);
}


/*
* 
*/
ScenePlayer.jump.cb = function(){
    Logger.write("[Player] jump callback; value = " + ScenePlayer.jump.value, "Player");
    $('#svecVideo2_50Z0').sfVideo2FF(ScenePlayer.jump.value / 1000);
    ScenePlayer.jump.value = 0;
    ScenePlayer.jumpPressed = false;
}

ScenePlayer.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("Player", resultCallback);
}

/*
* Hadles key down event
*/
ScenePlayer.prototype.handleKeyDown = function (keyCode) {
	Logger.write("ScenePlayer.handleKeyDown(" + keyCode + ")", "Player");
	// TODO : write an key event handler when this scene get focued
    /*try
    {*/
        ScenePlayer.showControls();
        switch (keyCode) {
            case sf.key.N0:
                ScenePlayer.handleNumPress("0");
                break;
            case sf.key.N1:
                ScenePlayer.handleNumPress("1");
                break;
            case sf.key.N2:
                ScenePlayer.handleNumPress("2");
                break;
            case sf.key.N3:
                ScenePlayer.handleNumPress("3");
                break;
            case sf.key.N4:
                ScenePlayer.handleNumPress("4");
                break;
            case sf.key.N5:
                ScenePlayer.handleNumPress("5");
                break;
            case sf.key.N6:
                ScenePlayer.handleNumPress("6");
                break;
            case sf.key.N7:
                ScenePlayer.handleNumPress("7");
                break;
            case sf.key.N8:
                ScenePlayer.handleNumPress("8");
                break;
            case sf.key.N9:
                ScenePlayer.handleNumPress("9");
                break;
            case sf.key.UP:
                ScenePlayer.handlePressUp();
                break;
            case sf.key.DOWN:
                ScenePlayer.handlePressDown();
                break;
			case sf.key.CH_UP:
				ScenePlayer.handleChUp();
				break;
			case sf.key.CH_DOWN:
				ScenePlayer.handleChDown();
				break;
            case sf.key.RETURN:
                widgetAPI.blockNavigation(event);
                ScenePlayer.stopAndReturn();
                break;    
             case sf.key.PLAY:
                ScenePlayer.play();
				break;
             case sf.key.FF:
                Logger.write("[Player] FF", "Player");
				if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted || ScenePlayer.streamType == StreamTypes.radio) {
                    return;
                }
                ScenePlayer.handlePressJump(ScenePlayer.jumpValue);
                break;
             case sf.key.REW:
                Logger.write("[Player] REW", "Player");
				if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted || ScenePlayer.streamType == StreamTypes.radio) {
                    return;
                }
                ScenePlayer.handlePressJump(-ScenePlayer.jumpValue);
                break;
            case sf.key.STOP:
                ScenePlayer.stopAndReturn();
                break;
			case sf.key.PAUSE:
				if (ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted || ScenePlayer.streamType == StreamTypes.radio) {
                    return;
                }
				ScenePlayer.pause();
				break;
			case sf.key.MUTE:
				$('#svecVideo2_50Z0').sfVideo2('setMute');
				break;
            case sf.key.BLUE:
				ScenePlayer.isPlaying = true;
                ScenePlayer.handleReturn();
                break;
            case sf.key.GREEN:
				if (ScenePlayer.streamType == StreamTypes.radio) {
					return;
				}
                ScenePlayer.handleGreenButton();
                break;
			case sf.key.YELLOW:
				if (ScenePlayer.sender == "Series" || ScenePlayer.sender == "ProgramEpisodes") {
					ScenePlayer.autoPlay = !ScenePlayer.autoPlay;
					ScenePlayer.setHelpBar();
				}
                break;
            default:
            //this functionality has treatment for other basic keys in your remote control. 
            // the keys has treatment are: PLAY, STOP, PAUSE, RW, FF
                if ((ScenePlayer.streamType == StreamTypes.live || ScenePlayer.streamType == StreamTypes.shifted || ScenePlayer.streamType == StreamTypes.radio) && (keyCode == sf.key.RW || keyCode == sf.key.FF || keyCode == sf.key.PAUSE))
                {
                    return;
                }
				$('#svecVideo2_50Z0').sfVideo2('RCKeyDefined', keyCode);
                break;
            case sf.key.RED:
                sf.scene.hide('Player');
                sf.scene.show('Settings');
                sf.scene.focus('Settings');
                SceneSettings.selectAccount();
                break;
            case sf.key.EXIT:
                widgetAPI.blockNavigation(event);
				ScenePlayer.handleExit();
                break;
        }
    /*}
    catch(ex)
    {
        ScenePlayer.stopAndReturn();
        ErrorHandler.HandleError(ex,"Player");
    }*/
}
