/**
 * @author Created by "Samsung"
 */

/**
 * @description This class define Radio page (radio scene)
 * @class
 * @param options
 */
function SceneRadio(options) {
	/**
	 * @description This property describes options of the class
	 * @property {object}
	 */
	this.options = options;
};

/**
 * @description This property describes language of the page (scene)
 * @property {string}
 * @default Default value is null
 */
SceneRadio.currentLang=null;

/**
 * @description <p>This function provides initializing prototype of the SceneRadio page.<br>
 * <i>It will be called only once when the scene manager show this scene first time
 * initialize the scene controls and styles, and initialize your variables here 
 * scene HTML and CSS will be loaded before this function is called</i></p>
 * @function
 */
SceneRadio.prototype.initialize = function () {
	Logger.write("SceneRadio.initialize()", "Radio");
		var loadjsCallback = function () {
			SceneRadio.initData();
			SceneRadio.currentLang = AppContext.ClientSettings.Language;
			SceneRadio.loadRadioPanel();
			
			SceneRadio.setHelpBar();
			$("#lblRadioTitle").empty();
			$("#lblRadioTitle").append(Resources.getResources().LabelRadio.toLowerCase());
			if (Helpers.is2011Model()) {
				$("#SceneRadio").addClass("old");
			}
		};
		if (!$("radioStations").ImageView) {
			sf.core.loadJS(["js/ImageView.js"], loadjsCallback);
		} else {
			loadjsCallback();
		}
};

/**
 * @description <p>This function provides initializing all required data of the SceneRadio page.</p>
 * @function
 */
SceneRadio.initData = function () {
	/**
	 * @description This property describes count of the visible radio stations
	 * @property {integer}
	 * @default Default value is 12
	 */
	SceneRadio.visibleStations = 12;
};

/**
 * @description <p>This function provides initializing help bar for radio page.</p>
 * @function
 */
SceneRadio.setHelpBar = function(){
    if (ScenePlayer.isPlaying) {
		$('#keysRadio').sfKeyHelp({
			'red':Resources.getResources().LabelSettings, 
			'green':Resources.getResources().Refresh, 
			'blue':Resources.getResources().Player, 
			'return':Resources.getResources().BackToMainMenu ,
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().ListenRadio, 
			'stop':Resources.getResources().Stop
		});
    } else {
		$('#keysRadio').sfKeyHelp({
			'red':Resources.getResources().LabelSettings, 
			'green':Resources.getResources().Refresh,
			'return':Resources.getResources().BackToMainMenu ,
			'updown':'', 'leftright':Resources.getResources().MoveCursor, 
			'enter':Resources.getResources().ListenRadio
		});                
    }
};

/**
 * @description <p>This function provides translates language-dependent parts of page (scene)</p>
 * @function
 */
SceneRadio.translate = function () {
     if (SceneRadio.currentLang != AppContext.ClientSettings.Language) {
		$("#radioNoData").html(Resources.getResources().NoData);
		$("#lblRadioTitle").empty();
		$("#lblRadioTitle").append(Resources.getResources().LabelRadio.toLowerCase());
		SceneRadio.currentLang = AppContext.ClientSettings.Language;
		SceneRadio.activePanel = "radio";
		if ($("#radioStations").ImageView) {
			SceneRadio.focusRadio();
		}
		SceneRadio.setHelpBar();
	}
};

/**
 * @description This property describes, which panel is now activated.
 * @property {string}
 * @default Default value is "radioPanel"
 */
SceneRadio.activePanel="radioPanel";

/**
 * @description <p>This function provides hiding image of loading and makes visible panels for radio stations.
 * Occurs when all data of the page (scene) are loaded.</p>
 * @function
 */
SceneRadio.onLoadDataCompleted = function(){
	if (SceneRadio.stations.length > 0) {
		Logger.write("Showing stations", "Radio");
		$('#radioStations').css('visibility', 'visible');
		$('#radioStations').show();
		$('#panelRadioSort').css('visibility', 'visible'); 
		SceneRadio.focusRadio();
	} else {
		$('#radioStations').css('visibility', 'hidden');
		$('#panelRadioSort').css('visibility', 'hidden'); 
		$("#radioNoData").show();
	}
	SceneRadio.hideLoading();
	/**
	 * @description This property describes the success of data loading.
	 * @property {boolean}
	 */
    SceneRadio.dataLoaded = true;
};

/**
 * @description <p>This function provides showing image of loading for Radio page (scene).</p>
 * @function
 */
SceneRadio.showLoading = function () {
	/**
	 * @description <p>This property describes that's the page now is loading or not.</p>
	 * @property
	 */
    SceneRadio.isLoading = true;
	if (AppContext.CurrentScene == "Radio") {
		Helpers.showLoading();
	}
    /*$('#radioStations').css('visibility', 'hidden');
    $('#panelRadioSort').css('visibility', 'hidden');  */
};

/**
 * @description <p>This function provides hiding image of loading for Radio page (scene).</p>
 * @function
 */
SceneRadio.hideLoading = function () {
	SceneRadio.isLoading = false;
	if (AppContext.CurrentScene == "Radio") {
		Helpers.hideLoading();
	}
};

/**
 * @description <p>This function prepares page (scene) to loading  data.</p>
 * @function
 */
SceneRadio.loadRadioPanel = function(){    
    SceneRadio.dataLoaded = true;
	
    SceneRadio.showLoading();          
    SceneRadio.loadListRadio(); 
};

/**
 * @description <p>This function provides loading radio stations for current user from server.</p>
 * @function
 */
SceneRadio.loadListRadio = function () {
	var errCallBack = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "Radio", true, textStatus, jqXHR);     
	};
	var callBack = function (result) {
		try {
			$("#radioStations").ImageView("clear");
			/**
			 * @description This property describes list of the loaded radio stations.
			 * @property {object[]}
			 */
			SceneRadio.stations = result.items;
			SceneRadio.stations = Helpers.sortByField(SceneRadio.stations, "name", true);
			SceneRadio.channelPicker = new ArchProgramPicker(SceneRadio.stations, SceneRadio.channelSetCallback);
			$('#scrollRadioStations').css({'visibility': 'hidden'});
			if (result.items.length > 0) {
				SceneRadio.bindRadio();
			}
			SceneRadio.onLoadDataCompleted();
		} catch (error) {
			ErrorHandler.HandleError(error, "Radio");  
		}
	};

	JsonServices.content.GetClientChannels(AppContext.user.sid, "Radio", null, null, callBack, errCallBack);
 };
 
/**
 * @description <p>This function provides binding the results of loading loadListRadio() function (list of radio stations) to DOM elements.</p>
 * @function
 */
 SceneRadio.bindRadio = function () {
	var pattern = AppContext.ImageUrlTemplate.replace("{1}", "10").replace("{2}", "1") + "&width=110";
	$("#radioStations").ImageView({
		elements: SceneRadio.stations,
		pageChangedCallback: SceneRadio.radioPageChanged,
		imageUrlPattern: pattern,
		patternFields: ["id"]
	});
	if (SceneRadio.visibleStations < SceneRadio.stations.length) {
		var pages = Math.ceil(SceneRadio.stations.length / SceneRadio.visibleStations);
		$('#scrollRadioStations').sfScroll({pages: pages});
		$('#scrollRadioStations').css({'visibility': 'visible'});
	}
 };
 
 /**
  * @description <p>This function sets callback on click radio station and playback of this station</p>
  * @function
  * @param {integer} index - This is index of selected radio station.
  * @param {function} successCallback - This is the method that occurs in the end of function.
  */
 SceneRadio.channelSetCallback = function (index, successCallback) {
	$("#radioStations").ImageView("move", index);
	var radio = SceneRadio.stations[index];
	SceneRadio.playRadio(radio);
	successCallback();
 };
 
 /**
  * @description <p>This function provides changing page on radio page (scene).</p>
  * @function
  * @param {integer} newPage - This is index of the moved page.
  */
 SceneRadio.radioPageChanged = function (newPage) {
	$('#scrollRadioStations').sfScroll("move", newPage - 1);
 };

 /**
  * @description <p>This function provides focusing on the panel of radio stations</p>
  * @function
  */
SceneRadio.focusRadio = function () {
	SceneRadio.activePanel = "radio";
	$("#radioStations").ImageView("focus");
};

/**
 * @description <p>This function provides events on action "move up" on page (scene)</p>
 * @function
 */
SceneRadio.handleUp = function () {
	try {
		if (SceneRadio.activePanel == "radio") {
			$("#radioStations").ImageView("moveUp");
			SceneRadio.channelPicker.count = $("#radioStations").ImageView("getIndex");
		}
	} catch (error) {
		ErrorHandler.HandleError(error,"Radio");  
	}  
};

/**
 * @description <p>This function provides events on action "move down" on page (scene). <br>
 * <i>Makes radio panel active and blurs sort panel if it was active</i></p>
 * @function
 */

SceneRadio.handleDown = function () {
	try {
		if (SceneRadio.activePanel == "radio") {
			$("#radioStations").ImageView("moveDown");
			SceneRadio.channelPicker.count = $("#radioStations").ImageView("getIndex");
		}
	} catch (error) {
		ErrorHandler.HandleError(error, "Radio");  
	}         
};

/**
 * @description <p>This function provides events on action "move left" on page (scene)</p>
 * @function
 */
SceneRadio.handleLeft = function () {
	try {
		if (SceneRadio.activePanel == "radio") {
			$("#radioStations").ImageView("moveLeft");
			SceneRadio.channelPicker.count = $("#radioStations").ImageView("getIndex");
		}
	} catch (error) {
		ErrorHandler.HandleError(error,"Radio");  
	}
};

/**
 * @description <p>This function provides events on action "move right" on page (scene)</p>
 * @function
 */
SceneRadio.handleRight = function () {
	try {
		if (SceneRadio.activePanel == "radio") {
			$("#radioStations").ImageView("moveRight");
			SceneRadio.channelPicker.count = $("#radioStations").ImageView("getIndex");
		}
	} catch (error) {
		ErrorHandler.HandleError(error,"Radio");
	}
};

/**
 * @description <p>This function provides playback of selected radio station</p>
 * @function
 * @param {object} station - Selected station.
 */
SceneRadio.playRadio = function (station) {
	var callback = function (result) {
		try {
			var radio = {
				url: result.URL,
				playlist: result.Playlist
			};
			radio.name = station.name;
			radio.imageUrl = AppContext.ImageUrlTemplate.replace("{0}", station.id).replace("{1}", "10").replace("{2}", "1") + "&width=132";
			radio.contentType = "Radio";
			sf.scene.hide(AppContext.CurrentScene);
			sf.scene.show('Player');
			sf.scene.focus('Player');
			ScenePlayer.setContent(radio, "Radio");
			SceneRadio.channelPicker.count = $("#radioStations").ImageView("getIndex");
		} catch (error) {
			ErrorHandler.HandleError(error, "Radio");  
		}
	 };
	var errCallback = function (jqXHR, textStatus, error) {
		ErrorHandler.HandleError(error, "Radio", true, textStatus, jqXHR);
	};
	
	JsonServices.media.GetClientStreamUri(
		AppContext.user.sid, "Radio", station.id,
		AppContext.ClientSettings.bAId, AppContext.ClientSettings.cdnId,
		AppContext.ClientSettings.qualityPreset, AppContext.ClientSettings.shiftTimeZoneName,
		callback, errCallback
	);
};

/**
 * @description <p>This function provides events on action "press enter" on page (scene). <br>
 * <i>Starting playback of selected radio station.</i></p>
 * @function
 */
SceneRadio.handleEnter = function () {
    try {
        if (SceneRadio.activePanel === "radio") {
			var station = SceneRadio.stations[$("#radioStations").ImageView("getIndex")];
			
			SceneRadio.playRadio(station);
        }
     } catch (error) {
        ErrorHandler.HandleError(error, "Radio");  
     }   
};

/**
 * @description <p>This function provides returns to Main menu</p>
 * @function
 */
SceneRadio.backToMainMenu = function(){
	try {
		sf.scene.hide('Radio');
		SceneMainMenu.show();
	} catch (error) {
		ErrorHandler.HandleError(error,"Radio");
	}
};

/**
 * @description <p>This function provides exiting from application</p>
 * @function
 */
SceneRadio.handleExit = function () {
	var resultCallback = function (result) {
		if (result) {
			AppEvents.Exit();
		}
	};
	SceneDialogPopUp.showExitDialog("Radio", resultCallback);
};

/**
 * @description <p>This function provides refresh radio page (scene)</p>
 * @function
 */
SceneRadio.refresh = function () {      
    try {
		SceneRadio.loadRadioPanel();
    } catch (error) {
		ErrorHandler.HandleError(error, "Radio");
    }    
};

/**
 * @description <p>This function will be called when the scene manager show this scene</p>
 * @function
 */
SceneRadio.prototype.handleShow = function () {
	Logger.write("SceneRadio.handleShow()", "Radio");
    SceneRadio.translate();
};

/**
 * @description <p>This function will be called when the scene manager hide this scene</p>
 * @function
 */
SceneRadio.prototype.handleHide = function () {
	Logger.write("SceneRadio.handleHide()", "Radio");
	Logger.write("Current scene (handleHide): " + AppContext.CurrentScene, "Player", true);
	Helpers.hideLoading();
};

/**
 * @description <p>This function will be called when the scene manager focus this scene</p>
 * @function
 */
SceneRadio.prototype.handleFocus = function () {
	Logger.write("SceneRadio.handleFocus()", "Radio");
    AppContext.CurrentScene = "Radio";
    if (ScenePlayer.isPlaying == true) {
		Helpers.setBackgroundOpacity();
	}
    SceneRadio.setHelpBar();
    if (ErrorHandler.NeedToRefresh[AppContext.CurrentScene]) {
            SceneRadio.refresh();
            ErrorHandler.NeedToRefresh[AppContext.CurrentScene] = false;
    } else if (SceneRadio.isLoading) {
		Helpers.showLoading();
	}
	Logger.write("Current scene (handleFocus): " + AppContext.CurrentScene, "Player", true);
};

/**
 * @description <p>This function will be called when the scene manager move focus to another scene from this scene</p>
 * @function
 */
SceneRadio.prototype.handleBlur = function () {
	Logger.write("SceneRadio.handleBlur()", "Radio");
};

/**
 * @description <p>This function will be called when user press any button</p>
 * @function
 * @param {}
 */
SceneRadio.prototype.handleKeyDown = function (keyCode) {
	Logger.write("SceneRadio.handleKeyDown(" + keyCode + ")", "Radio");
	// TODO : write an key event handler when this scene get focused
    if (!SceneRadio.dataLoaded)
        return;
    if (Helpers.handleGlobalKeys(keyCode)) {
		return;
	}    
	switch (keyCode) {
		case sf.key.LEFT:
            SceneRadio.handleLeft();
			break;
		case sf.key.RIGHT:
            SceneRadio.handleRight();        
			break;
		case sf.key.UP:
            SceneRadio.handleUp();
			break;
		case sf.key.DOWN:
            SceneRadio.handleDown();
			break;
		case sf.key.ENTER:
            SceneRadio.handleEnter();
			break;
        case sf.key.RETURN:
            widgetAPI.blockNavigation(event);
            SceneRadio.backToMainMenu();
            break;   
		case sf.key.BLUE:
            if  (ScenePlayer.isPlaying == true)
            {
                sf.scene.hide('Radio');
                sf.scene.show('Player');
                sf.scene.focus('Player');
            }
            break;
        case sf.key.STOP:
            if  (ScenePlayer.isPlaying == true)
            {
                    ScenePlayer.stop();
                    SceneRadio.setHelpBar();
            }
            break;		
        case sf.key.GREEN:
            try
            {
                SceneRadio.refresh();
             }
            catch(error)
            {
                 ErrorHandler.HandleError(error,"Radio");
            }    
            break;      
		case sf.key.RED:
            try
            {
                sf.scene.hide('Radio');
                sf.scene.show('Settings');
                sf.scene.focus('Settings');
                SceneSettings.selectAccount();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"Radio");  
            }  
            break;
		case sf.key.EXIT:
            try
            {
                widgetAPI.blockNavigation(event);
				SceneRadio.handleExit();
            }
            catch(error)
            {
                ErrorHandler.HandleError(error,"Radio");  
            }  
            break;     
        default:         
            widgetAPI.blockNavigation(event);
            break;
	}
};
