
/**
 * @class Service playlist. Works with information about media stream.
 */
ASXLoader = {};

/**
 * @field
 * @description Array that stores start times of asx entries
 * @default []
 */
ASXLoader.arrayStartTimes = []; 

/**
 * @field
 * @description Array that stores urls of asx entries
 * @default []
 */
ASXLoader.arrayAsxList = [];

/**
 * @field
 * @description Array that stores durations of asx entries
 * @default []
 */
ASXLoader.arrayDurations = [];

/**
 * @field
 * @description Current asx entry index
 * @default -1
 */
ASXLoader.currentUrlIndex = -1;

/**
 * @field
 * @description Callback that occurs when asx file content has received
 * @default null
 */
ASXLoader.successCallback = null;

/**
 * @field
 * @description Array thats stores duration of the programs.
 * @default []
 */
ASXLoader.programsDuration = [];

/**
 * @field
 * @description Stores value that indicates whether next asx entry exists
 * @default true
 */
ASXLoader.hasNext = true;

/**
 * @field
 * @description Stores value that indicates whether preview asx entry exists
 * @default false
 */
ASXLoader.hasPrev = false;

/**
 * @field
 * @description Stores value that indicates whether asx entry exists
 * @default false
 */
ASXLoader.hasPlayList = false;

/**
 * @function
 * @description Provides checking: is the current asx entry first
 * @return {bool}
 */
ASXLoader.isFirst = function(){
    return ASXLoader.currentUrlIndex == 0;
};

/**
 * @function
 * @description Converts time from HH:mm:ss format to seconds
 * @param {string} stringTime - time in HH:mm:ss format.
 * @return time in seconds format.
 */
ASXLoader.convertTime = function(stringTime){
    var arrTime = stringTime.split(":");
    
    var hour = 0;
    var min = 0;
    var sec = 0;
    
    if (arrTime.length > 2)
    {
        hour = parseInt(arrTime[0], 10)*60*60;        
        min = parseInt(arrTime[1], 10)*60;        
        sec = parseInt(arrTime[2], 10);        
    }
    else if (arrTime.length > 1)
    {
        min = parseInt(arrTime[0], 10)*60;        
        sec = parseInt(arrTime[1], 10);        
    }
    else if (arrTime.length > 0)
    {
        sec = parseInt(arrTime[0], 10);        
    }
    
    return sec + min + hour;    
};

/**
 * @function
 * @description Parses xml from $ajax get
 * @param xml - incoming xml information about playlist.
 */
ASXLoader.parse = function(xml){
    //init
    count = 0;
    ASXLoader.arrayAsxList = [];
    ASXLoader.currentUrlIndex = -1;
    ASXLoader.hasNext = true;
    ASXLoader.arrayStartTimes = [];
    ASXLoader.arrayDurations = [];

      var i = 0;
     $(xml).find('ENTRY').each(function(){       
     
         $(this).find('REF').each(function(){
            var href = $(this).attr('HREF');
            ASXLoader.arrayAsxList[i] = href;        
        }); 
             
         $(this).find('DURATION').each(function(){
            var duration = $(this).attr('VALUE');
            ASXLoader.arrayDurations[i] = ASXLoader.convertTime(duration);        
        }); 
        
         $(this).find('STARTTIME').each(function(){
            var startTime = $(this).attr('VALUE');
            ASXLoader.arrayStartTimes[i] = ASXLoader.convertTime(startTime);     
        });
        i++;
    }); 
    
    xml = null;
	if (ASXLoader.successCallback && typeof(ASXLoader.successCallback) == "function")
	{
		ASXLoader.successCallback();    
	}
    ASXLoader.hasPlayList = true;
    for (var j = 0 ; j < ASXLoader.arrayAsxList.length; j++)
    {
        Logger.write("href["+j+"]="+ASXLoader.arrayAsxList[j], "ASXLoader");
        Logger.write("duration["+j+"]="+ASXLoader.arrayDurations[j], "ASXLoader");
        Logger.write("starttime["+j+"]="+ASXLoader.arrayStartTimes[j], "ASXLoader");
    }    
};

/**
 * @function
 * @description Gets file contents from url
 * @param url - incoming url
 * @param cb - callback occurs after received asx file's content.
 * @param errorCb - callback occurs on error in receiving.
 */
ASXLoader.load = function(url, cb, errorCb){
    ASXLoader.successCallback = cb || function(){};
    $.ajax({
            type: "GET",
            url: url,
            dataType: "xml",
            error: errorCb || function(){},
            timeout: Options.timeout,
            success: ASXLoader.parse});                                       
};

/**
 * @function
 * @description Gets start time for current asx entry
 * @return {integer}
 */
ASXLoader.getCurrentStartTime = function(){
    ASXLoader.check();
    //Logger.write("[ASXLoader] return start time=" + ASXLoader.arrayStartTimes[ASXLoader.currentUrlIndex], "ASXLoader");
    return ASXLoader.arrayStartTimes[ASXLoader.currentUrlIndex] || 0;
};

/**
 * @function
 * @description Sets start time for current asx entry 
 */
ASXLoader.setCurrentStartTime = function(startTime){
    ASXLoader.check();
    return ASXLoader.arrayStartTimes[ASXLoader.currentUrlIndex] = startTime;
};

/**
 * @function
 * @description Gets url for of current entry
 */
ASXLoader.getCurrentUrl = function(){
    ASXLoader.check();
    var result = ASXLoader.arrayAsxList[ASXLoader.currentUrlIndex];    
    return result;
};

/**
 * @function
 * @description Gets duration for current asx entry 
 */
ASXLoader.getCurrentDuration = function(){
    ASXLoader.check();
    //var timeToJump = ASXLoader.getCurrentStartTime();
    //var duration = ASXLoader.arrayDurations[ASXLoader.currentUrlIndex] || 0; 
	var duration = parseInt(ASXLoader.arrayDurations[ASXLoader.currentUrlIndex], 10);
	duration += parseInt(ASXLoader.arrayStartTimes[ASXLoader.currentUrlIndex], 10);
	duration = duration || 0;
	// if (duration > 0)
	//     duration += timeToJump;
    return duration * 1000;
};

/**
 * @function
 * @description Gets duration for previous asx entry 
 */
ASXLoader.getPrevDuration = function(){
    ASXLoader.check();    
    var prevDuration = 0;
    for (var i = 0; i < ASXLoader.currentUrlIndex ; i++) {
		var duration = parseInt(ASXLoader.arrayDurations[i], 10) + parseInt(ASXLoader.arrayStartTimes[i], 10);
        prevDuration += duration || 0;     
    }    
	
    //Logger.write("[ASXLoader] past time="+prevDuration, "ASXLoader");
    return prevDuration;
};

/**
 * @function
 * @description Gets summary duration for all durations 
 */
ASXLoader.getTotalDuration = function () {
	ASXLoader.check();
	var totalDuration = 0;
	for (var i = 0; i < ASXLoader.arrayDurations.length; i++) {
		totalDuration += ASXLoader.arrayDurations[i];
	}
	
	return totalDuration * 1000;
};

/**
 * @function
 * @description Initializes arrays
 */
ASXLoader.check = function(){
    if (!ASXLoader.hasPlayList)
    {
        ASXLoader.arrayStartTimes = []; 
        ASXLoader.arrayAsxList = [];
        ASXLoader.arrayDurations = [];
    }
};

/**
 * @function
 * @description Gets url for of next entry
 */
ASXLoader.getNextUrl = function(){
    ASXLoader.hasPlayList = ASXLoader.hasNext;
    ASXLoader.check();
    ASXLoader.currentUrlIndex++;
    Logger.write("[ASXLoader] Get url #" + ASXLoader.currentUrlIndex, "ASXLoader");    
    var result = ASXLoader.hasNext ? ASXLoader.arrayAsxList[ASXLoader.currentUrlIndex] : null;
    ASXLoader.hasNext = ASXLoader.currentUrlIndex + 1 < ASXLoader.arrayAsxList.length;
    ASXLoader.hasPrev = ASXLoader.currentUrlIndex > 0;
    Logger.write("[ASXLoader] Has next entry =" + ASXLoader.hasNext, "ASXLoader");
    return result;
};

/**
 * @function
 * @description Gets url for of preview entry
 */
ASXLoader.getPrevUrl = function(){
    ASXLoader.check();
    ASXLoader.hasPrev = ASXLoader.currentUrlIndex > 0;
    ASXLoader.hasPrev ? ASXLoader.currentUrlIndex-- :ASXLoader.currentUrlIndex;
    ASXLoader.hasNext = ASXLoader.currentUrlIndex + 1 < ASXLoader.arrayAsxList.length;
    Logger.write("[ASXLoader] Get url #" + ASXLoader.currentUrlIndex, "ASXLoader");    
    var result = ASXLoader.hasPrev ? ASXLoader.arrayAsxList[ASXLoader.currentUrlIndex] : null;        
    return result;
};

/**
 * @function
 * @description Loading information about duration of the programs.
 * @param programs
 */
ASXLoader.loadProgramsDuration = function (programs) {
	Logger.write("Loading durations", "ASXLoader", true);
	this.programsDuration = [];
	for (var i = 0; i < programs.length; i++) {
		this.programsDuration[i] = programs[i].length * 60;
		Logger.write("this.programsDuration['" + i + "' = " + this.programsDuration[i], "ASXLoader", true);
	}
};


/**
 * @function
 * @description Provides getting information about start and duration parameters of current section.
 * @param currentTime - time in seconds
 */
ASXLoader.getCurrentSection = function (currentTime) { // time in seconds
	var startTime = ASXLoader.arrayStartTimes[0];
	Logger.write("CurrentTime: " + currentTime, "ASXLoader", true);
	Logger.write("StartTime: " + startTime, "ASXLoader", true);
	if (currentTime <= startTime) {
		return {
			start: 0,
			duration: startTime
		};
	}
	
	
	for (var i = 0; i < ASXLoader.programsDuration.length; i++) {
		startTime += ASXLoader.programsDuration[i];
		Logger.write("for i == '" + i + "', StartTime = " + startTime, "ASXLoader", true);
		if (startTime >= currentTime) {
			return {
				start: startTime - ASXLoader.programsDuration[i],
				duration: ASXLoader.programsDuration[i]
			};
		}
	}
};