
/**
 * @class Class provides work with channels.
 * @param maxChannels - maximal count of the channels
 * @param setCallback - channel's callback
 */
ChannelPicker = function(maxChannels, setCallback){
	/**
	 * @field
	 * @description Channel's callback
	 * @default function() {}
	 */
    this.setCallback = setCallback || function(){};
    /**
	 * @field
	 * @description Maximal count of the channels
	 */
    this.maxChannels = maxChannels;
    /**
	 * @field
	 * @description Channel number that must be set.
	 * @default ""
	 */
    this.channelToSet = "";
    /**
	 * @field
	 * @description Channel that now is set.
	 * @default ""
	 */
    this.settedChannel = "";
    /**
	 * @field
	 * @description Describes whether the channel is set.
	 * @default false
	 */
    this.setted = false;
    
    /**
	 * @function
	 * @description Gets current channel
	 */
    this.getCurrentChannel = function(){
        var currentChannel = this.channelToSet;
        var length = (this.maxChannels + "").length;
        while (currentChannel.length != length)
        {
            currentChannel += "-";
        }
        return currentChannel;
    };
    
    /**
	 * @function
	 * @description Gets current channel without symbol '-'
	 */
    this.getSettedChannel = function() {
        Logger.write("channel="+this.settedChannel, "ChannelPicker");
        return this.settedChannel.replace("-", "");
    };
    
    /**
	 * @function
	 * @description Occurs when number button pressing
	 * @param key - key pressed.
	 */
    this.numPressed = function(key){
        var num = parseInt(this.channelToSet + key, 10);
        if (num <= this.maxChannels)
        {
			this.channelToSet += key;
        }
        if (typeof(this.numTimeout) != "undefined")
        {
			clearTimeout(this.numTimeout);
        }
        
        var cb = this.setChannel;
        var self = this;
        
        this.numTimeout = setTimeout(function(){cb(self);}, 2000);   
    };

    /**
	 * @function
	 * @description Sets the channel
	 * @param self - ChannelPicker class
	 */
    this.setChannel = function(self){        
        channel = parseInt(self.channelToSet, 10);
        if (channel > 0 && channel <= self.maxChannels)
        {
			var valueToSet = self.channelToSet;
			var cb = function () {
				self.settedChannel = valueToSet;
			};
            self.setCallback(channel, cb);
        }
        self.setted = true;
        self.channelToSet = "";
    };
    
    /**
	 * @function
	 * @description Sets the channel 
	 * @param channel - channel.
	 * @param self - ChannelPicker class
	 */
    this.setChannelManual = function(channel, self){        
        channel = parseInt(channel, 10);
        if (channel > 0 && channel <= self.maxChannels)
        {
			var valueToSet = channel + "";
			var cb = function () {
				self.settedChannel = valueToSet;
			};
            self.setCallback(channel, cb);
        }        
        self.channelToSet = "";
    };
    
    /**
	 * @function
	 * @description Sets next channel 
	 */
    this.setNext = function(){        
        var channel = parseInt(this.settedChannel, 10);
        if ((channel + 1) <= this.maxChannels)
        {
            channel++;
            this.channelToSet = channel + "";
            this.setChannel(this);
        }        
    };
    
    /**
	 * @function
	 * @description Sets preview channel 
	 */
    this.setPrev = function(){        
        var channel = parseInt(this.settedChannel, 10);
        if ((channel - 1) > 0)
        {
            channel--;
            this.channelToSet = channel + "";
            this.setChannel(this);
        }        
    };
};

/**
 * @class Class provides work with archive programs.
 * @param programs - programs from the archive.
 * @param setCallback - program's callback
 * @param index - programs's index.
 */
ArchProgramPicker = function (programs, setCallback, index) {
	/**
	 * @field
	 * @description Maximal count of the channels
	 */
    this.count = programs.length;
    /**
	 * @field
	 * @description program's callback
	 * @default function(){}
	 */
    this.setCallback = setCallback || function(){};
    /**
	 * @field
	 * @description index of the program
	 * @default 0
	 */
    this.index = index || 0;
    
    /**
	 * @function
	 * @description Sets next program in array
	 */
    this.setNext = function () {
        if (this.index < (this.count - 1)) {
            this.index++;
            this.setCallback(this.index);
			return true;
        }
    };

    /**
	 * @function
	 * @description Sets preview program in array
	 */
    this.setPrev = function () {
        if (this.index > 0) {
            this.index--;
            this.setCallback(this.index);
			return true;
        }    
    };
};