/**
 * @author Samsung
 */

/**
 * @class Class provides work with errors.
 */
ErrorHandler={};

/**
 * @field
 * @description Describes the need of refreshing page
 */
ErrorHandler.NeedToRefresh = {"LiveTv": false,"ArchTv":false, "ArchPlus": false, "Movies2":false, "Radio": false,"Settings": false, "MainMenu": false, "Favorites": false};

/**
 * @function 
 * @description Handles errors, that occurs in application
 * @param {string} error - text of the error.
 * @param {string} sender - object which sent error.
 * @param {boolean} isOnServer - server side error or not.
 * @param {string} textStatus - text of status error (timeout for example)
 * @param info
 */
ErrorHandler.HandleError = function (error, sender, isOnServer, textStatus, info) {
	/**
	 * @field
	 * @description message of the error.
	 * @default ""
	 */
    var errorMessage = "";
    /**
	 * @field
	 * @description error is on server side or not.
	 * @default false
	 */
    var isServerError = isOnServer||false;
    /**
	 * @field
	 * @description contains sender of the error.
	 */
    var backTo = sender;
    /**
     * @field
     * @default false
     */
    var info = info || false;
    if (isServerError) {
		if ((sender != "Login") && (sender.indexOf("Search") == -1)) {
			backTo = "MainMenu";
		}
		if (textStatus == "timeout") {
			errorMessage = Resources.getResources().TimeoutError;
		} else {
			if (jqXHR.status == 401) {
                errorMessage = Resources.getResources().SceneLoginLoginError;
			} else {
				errorMessage = Resources.getResources().ServiceError;
				if (typeof(error) != "undefined") {
					errorMessage += " " + Resources.getResources().Message + ": " + error.toString();
				}
			}
		}
    } else {
		 errorMessage = Resources.getResources().AnErrorOccured;
		 if (typeof(error) != "undefined") {
			errorMessage += "&nbsp;" + Resources.getResources().Message + ": " + error.toString();
			/*Logger.write("error=" + error.toString(), "ErrorHandler");
			Logger.write("fileName=" + error.fileName, "ErrorHandler");
			Logger.write("lineNumber=" + error.lineNumber, "ErrorHandler");
			Logger.write("stack trace: " + error.stack, "ErrorHandler");*/
			var callstack = [];
			var currentFunction = arguments.callee.caller;
			while (currentFunction) {
				var fn = currentFunction.toString();
				//var fname = fn.substring(fn.indexOf("function") + 8, fn.indexOf('')) || 'anonymous';
				callstack.push(fn);
				currentFunction = currentFunction.caller;
			}
			Logger.write("stack trace: " + callstack.join("\n\n"), "ErrorHandler");
		 }            
    } 
    
    if (sender == "Login") {
		if (!info) {
			Logger.write("Error in login screen", "ErrorHandler", true);
            $("#SceneLogin #lblError").sfLabel({text: errorMessage});
		}
		return;
    }
        
    if ((sender == "PopUp") || (AppContext.CurrentScene == "PopUp")) {
            ScenePopUp.close();
            backTo = ScenePopUp.sender;
    }
    
	var prevState = ErrorHandler.NeedToRefresh[sender];
    ErrorHandler.NeedToRefresh[sender] = true;
    
    if (sender == "ServicePlayer") {
            errorMessage = error.toString();
            ErrorHandler.NeedToRefresh[sender] = false;
    }
    
    if (info && !prevState) {
            errorMessage = error.toString();
            ErrorHandler.NeedToRefresh[sender] = false;
    }
        
    sf.scene.show('ErrorPopUp');
    $('#SceneErrorPopUp').data("error", errorMessage);
    $('#SceneErrorPopUp').data("sender", backTo);         
    sf.scene.focus('ErrorPopUp'); 
};