/**
 * @class Class that provides service operations for helping application in work
 */
var Helpers = {

};

/**
 * @function c
 * @description Gets login data from parameters string
 * @param params - string with parameters
 */
Helpers.getLoginData = function (params) {
	return this.getParamsValues(params, ['id', 'pw']);
};

/**
 * @function 
 * @description Set input tools language (keyboard for ex.) 
 * @param lang - language.
 */
Helpers.setImeLanguage = function (lang) {
	Logger.write("=====Updating IMELang, current: " + _g_ime.IMElang + "; new: " + lang, "Helpers");
	//var imePlugin = document.getElementById("pluginObjectIME");
	_g_ime.IMElang = lang;
	_g_ime.OSDlang = lang;
	_g_ime.updateIMElang(lang);
	_g_ime.updateOSD(lang);
	//imePlugin.SetLanguage(lang.toUpperCase());
	Logger.write("=====IMELang updated, new: " + _g_ime.IMElang, "Helpers");
};

/**
 * @function 
 * @description Decodes html symbols
 * @param value - text to decode.
 */
Helpers.decodeHtml = function (value) {
    if (value) {
        return jQuery('<div/>').html(value).text(); 
    } else {
        return '';
    }
};

/**
 * @function 
 * @description Get params values from params string
 * @param params - string with params
 * @param paramNames - array with param names
 */
Helpers.getParamsValues = function (params, paramNames)
{
    if (params.charAt(0) == "?")
    {
        params = params.slice(1, params.length);
    }
    
    params = params.split("&");
    var result = [];
    
    for (var i = 0; i < params.length; i++)
    {
        var data = params[i].split("=");
        if (data.length == 2)
        {
            for (var j = 0; j < paramNames.length; j++)
            {
                if (data[0] == paramNames[j])
                {
                    result[j] = data[1];
                    break;
                }
            }
        }
    }
    
    return result;
};

/**
 * @function 
 * @description Escapes html code
 * @param str - unescaped string
 */
Helpers.escapeHTML = function(str)
{
   var div = document.createElement('div');
   var text = document.createTextNode(str);
   div.appendChild(text);
   return div.innerHTML;
};

/**
 * @function 
 * @description Unescapes html code
 * @param str - escaped string
 */
Helpers.unescapeHTML = function (str) {
	var e = document.createElement('div');
	e.innerHTML = str;
	return e.childNodes.length === 0 ? "" : e.childNodes[0].nodeValue;
};

/**
 * @function 
 * @description convert char to special html-entities (such as &#xa0)
 * @param str - element to convert.
 */
Helpers.toNumCharReference = function (str) {
  ret = "";
  for (var i = 0; i < str.length; i++) 
    ret += "&#x" + str.charCodeAt(i).toString(16).toUpperCase() + ";"; 
  return ret;
};

/**
 * @function 
 * @description Remove quotes from string
 * @param str - string with quotes.
 */
Helpers.removeQuotes = function(str)
{
    return str.replace(/'/g, "");
};

/**
 * @function 
 * @description Parse aspect ratio.
 * @param darStr - stroke with ar (4:3 for ex.)
 */
Helpers.parseAr = function (darStr) {
	if (!darStr || darStr.indexOf(":") < 0)
	{
		return {x: 4, y: 3};
	}
	
	var parts = darStr.split(":");
	return {
		x: parseInt(parts[0]),
		y: parseInt(parts[1])
	};
};

/**
 * @function 
 * @description Sorts input array by field name.
 * @param array - input array
 * @param fieldName - sort criteria
 * @param isAscending - if true - ascending sort, otherwise - descending
 * @param subFieldName - sort criteria on second level.
 */
Helpers.sortByField = function (array, fieldName, isAscending, subFieldName) {
	Logger.write("===Begin sorting...", "Helpers");
    var fieldExists = !!array[0] && (!!array[0][fieldName] || array[0][fieldName] === 0);
    if (!fieldExists || (!!subFieldName && !array[0][fieldName][subFieldName])) {
        Logger.write("===Can't sort!", "Helpers");
        return array;
    }
    
    if (!isAscending && isAscending !== false) {
		isAscending = true;
	}
	
    var sortFunc = function (a, b) {
        var aField = !subFieldName ? a[fieldName] : a[fieldName][subFieldName];
        var aField = typeof(aField) === "string" ? $.trim(aField) : aField;
        var bField = !subFieldName ? b[fieldName] : b[fieldName][subFieldName];
        var bField = typeof(bField) === "string" ? $.trim(bField) : bField;
        if (isAscending) {
            return aField > bField ? 1 : -1;
        } else {
            return aField < bField ? 1 : -1;
        }
        //return 0;
    };
    Logger.write("===Sorting completed...", "Helpers");
    return array.sort(sortFunc);
};

/**
 * @function 
 * @description Add zero's to number (for ex. 3 => 03 in time 12:3)
 * @param number - number for add
 * @param numSize - count of the zero
 */
Helpers.addZeros = function (number, numSize) {
	if (!number && number !== 0) {
		return;
	}
	number = number.toString();
	numSize = numSize || 2;
	
	while (number.length < numSize) {
		number = "0" + number;
	}
	
	return number;
};

/**
 * @function 
 * @description Return focus on specified scene
 * @param scene - page for return focus
 */
Helpers.returnFocus = function (scene) {
	if (!scene || typeof(scene) !== "string") {
		scene = AppContext.CurrentScene;
	}
	
	sf.scene.returnFocus();
	sf.scene.focus(scene);
};

/**
 * @function 
 * @description Display loading element
 */
Helpers.showLoading = function () {
	$('#loadingObject').sfLoading('show');
};

/**
 * @function 
 * @description Hide loading element
 */
Helpers.hideLoading = function () {
	$('#loadingObject').sfLoading('hide');
};


/**
 * @class Helper class for EPG (Electronic Program Guide)
 */
var EpgHelper = {

};

/**
 * @field
 * @description padding of the table.
 * @default 10
 */
EpgHelper.tablePadding = 10;

/**
 * @function
 * @description Provides getting the table of the channel in html.
 */
EpgHelper.getChannelTableHtml = function ($$$) {
	var widths, max, theend;
	var tableMaxWidth  = 680;
	var tablePadding = 10;
	var programSpacing = 3;

	var addWidth = function (width, i, length) {
		if (width < 0)
			return 0;
			
		width = Math.ceil(width);
		
		if ((width + tablePadding) >= max)
		{
			widths.push(max);
			theend = true;
			return max;
		}    
		else 
		{
			max -= width + tablePadding + programSpacing;
			widths.push(width);
			return width;
		}
	};

	var empty = function () {
		widths = [];
		max = tableMaxWidth;
		theend = false;
	};
	
	/**
	 *@function 
	 *@description [PRIVATE] Gets width for program button
	 *@param startTime - program start time
	 *@param endTime - program end time
	 *@param interval - EPG interval
	 */
	var getProgramButtonWidth = function(startTime, endTime, interval)
	{
		var result = (endTime.getTime()-startTime.getTime())*100/interval;
		result = result * tableMaxWidth/100;
		return result;
	};
	
	/**
	 *@function 
	 *@description [PRIVATE] Gets td HTML code for programs table
	 *@param width - td width in percent
	 *@param programData - data for program
	 */
	var getProgramTableTd = function(width, programData)
	{
		if (width <= 0)
			return "";
			
		var programBtnStyle = "width: 100%;";
		var style = "width: "+width.toString()+"px;padding-right:10px;";
		var tdHtml = "<td style='padding:0px;'>";
		var id = "btnProgram" + programData.id;
		tdHtml += "<div id='" + id + "' style='" + style +
			"' data-start-time='" + DateHelper.convertToString(programData.startTime) +
			"' data-description='" + programData.description +
			"' data-image-count='" + programData.imageCount +
			"' data-id='" + programData.id +
			"' class='programOuterDiv'><div align='left' class='programButton' style='" + programBtnStyle + "'>&nbsp;&nbsp;" +
			Helpers.decodeHtml(Helpers.escapeHTML(programData.name)) + "</div></div>";
		tdHtml += "</td>";
		
		return tdHtml;
	};
	
	
	return function(channelId, programsData, startTime, interval, currentChannel)
	{
		var html = "<table class='channelTable' id='tableChannel" + channelId + "' cellpadding='1px' cellspacing='1px'><tr style='padding-bottom:-2px;margin-bottom:-2px;'>";
		var endTime = new Date();
		endTime.setTime(startTime.getTime()+interval);     
	   
		if (!programsData || programsData.length == 0)
		{
			var unavailableId = "btnUnavail" + channelId;
			var uwidth = tableMaxWidth + tablePadding;
			 html += "<td style='padding:0px;'><div id='"+unavailableId+"' style='width:"+uwidth.toString()+"px;overflow: hidden;' programDescription='Unavailable' class='programOuterDiv'><div class='programButton' style='width:100%;'>&nbsp;&nbsp;Unavailable</div></div></td>";
			currentChannel.push("#"+unavailableId);
		}
		else
		{
			var firstAdded = false;
			var width = 0;
			var length = programsData.length;
			empty();
			
			for (var i=0; i < length; i++)
			{
				var program = programsData[i];
				if (!firstAdded && !theend)
				{
					if (program.startTime > startTime)
					{
						width = getProgramButtonWidth(startTime, program.startTime, interval);
					   
						width = addWidth(width, i, length);
						if (i > 0)
						{
							html += getProgramTableTd(width, programsData[i-1]);
							currentChannel.push("#btnProgram" + programsData[i-1].id);
						}
						else
						{
							var unavailableId = "btnUnavail" + channelId;
							html += "<td style='padding:0px;'><div id='"+unavailableId+"' style='width:"+width.toString()+"px;overflow: hidden;padding-right:10px' programDescription='Unavailable' class='programOuterDiv'><div class='programButton' style='width:100%;'>&nbsp;&nbsp;Unavailable</div></div></td>";                       
							currentChannel.push("#"+unavailableId);
						}    
						firstAdded = true;
					}
					else if (i == (length - 1))
					{
						width = getProgramButtonWidth(startTime, endTime, interval);
						width = addWidth(width, i, length);
						html += getProgramTableTd(width, programsData[i]);
						currentChannel.push("#btnProgram" + programsData[i].id);
					}
				}

				if (firstAdded && !theend)
				{
					var style = "";
					width = 0;
					if (i == (length - 1))
					{
						width = getProgramButtonWidth(program.startTime, endTime, interval);
					}
					else 
					{
						width = getProgramButtonWidth(program.startTime, programsData[i+1].startTime, interval);
					}
					width = addWidth(width, i, length);
					html += getProgramTableTd(width, program);
					currentChannel.push("#btnProgram" + program.id);
				}
			}
		}
		
		html += "</div>";
		return html;
	};
	
}(document);

/**
 *@function 
 *@description Creates channel table
 *@param channelId - Channel ID
 *@param programsData - array with programs data
 *@param startTime - EPG start time
 *@param interval - EPG time interval
 */
EpgHelper.createChannelTable = function (channelId, programsData, startTime, interval, currentChannel)
{
    var table = $(this.getChannelTableHtml(channelId, programsData, startTime, interval, currentChannel));
    return table;
};

/**
 * @class Provides help in work with data.
 */
var DateHelper = {
    
};

/** 
 * @function
 * @description Parses date from string (example: 2007-11-23T13:11:22)
 * @param dateString - date in services format
 */
DateHelper.parseDate = function(dateString)
{
    if (typeof(dateString)!="undefined")
    {
		if (typeof(dateString) == "object") {
			return dateString;
		}
		var rx = /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2})/;
		var res = rx.exec(dateString);
		var result = new Date(res[1], res[2]-1, res[3], res[4], res[5], res[6]);
		return result;
    }
    else
    {
		return null;
    }
};

/** 
 * @function
 * @description Converts javascript date to services format
 * @param date - date to convert
 */
DateHelper.convertToString = function (date) {
    return DateHelper.dateToString(date, "%Y-%m-%dT%H:%M:%S");
};

/** 
 * @function
 * @description Getting Date to display in data panel on Archive page
 * @param date - date to convert
 */
DateHelper.getArchDate = function (date) {
	 var archDate = DateHelper.getShortDay(date)+", "+DateHelper.getShortMonth(date)+" "+date.getDate().toString();  
	 return archDate;
};

/** 
 * @function
 * @description Getting Date to display in data panel on Archive plus page
 * @param date - date to convert
 */
DateHelper.getArchPlusDate = function (date) {
	return date.getDate() + " " + DateHelper.getShortMonth(date) + " " + date.getFullYear();
};

/** 
 * @function
 * @description Getting Date to display in data panel on Messages page
 * @param date - date to convert
 */
DateHelper.getMessageDateTime = function (date) {
	var result = date.getDate() + " " + DateHelper.getShortMonth(date) + " " + date.getFullYear();
	result += " " + DateHelper.getTime(date);
	return result;
};

/** 
 * @function
 * @description Getting Time to display 
 * @param date - date to convert
 * @param withSeconds - date with seconds or not
 * @param withSpaces - date with space (" : ") or not (":")
 */
DateHelper.getTime = function (date, withSeconds, withSpaces) {
	var hours = Helpers.addZeros(date.getHours());
	var minutes = Helpers.addZeros(date.getMinutes());
	
	var time = hours;
	time += withSpaces ? " : " : ":";
	time += minutes;
	
	if (withSeconds) {
		var seconds = Helpers.addZeros(date.getSeconds());
		time += withSpaces ? " : " : ":";
		time += seconds;
	}
	
	return time;
};

/** 
 * @field
 * @description Contains types of date and time and functions of getting for them
 */
DateHelper.formats = {
	"%H": { func: "getHours", zeros: 2 },
	"%M": { func: "getMinutes", zeros: 2 },
	"%S": { func: "getSeconds", zeros: 2 },
	"%d": { func: "getDate", zeros: 2 },
	"%m": { func: function (date) { return Helpers.addZeros(date.getMonth() + 1, this.zeros); }, zeros: 2 },
	"%Y": { func: "getFullYear", zeros: 4 }
};

/** 
 * @function
 * @description Provides converting date to string by the format
 * @param date - date to convert
 * @param format - format for converting
 */
DateHelper.dateToString = function (date, format) {
	var callstack = [];
	var currentFunction = arguments.callee.caller;
	while (currentFunction) {
		var fn = currentFunction.toString();
		callstack.push(fn);
		currentFunction = currentFunction.caller;
	}
	for (key in DateHelper.formats) {
		if (format.indexOf(key) > -1) {
			var tmpFormat = DateHelper.formats[key];
			var value = typeof(tmpFormat.func) === "string" ? Helpers.addZeros(date[tmpFormat.func](), tmpFormat.zeros) : tmpFormat.func(date);
			format = format.replace(key, value);
		}
	}
	
	return format;
};

/** 
 * @function
 * @description Gets short day name from javascript date
 * @param date
 */
DateHelper.getShortDay = function (date) {
    var day = date.getDay();
    var days = [];
    days[0] = Resources.getResources().Su;
    days[1] = Resources.getResources().Mo;
    days[2] = Resources.getResources().Tu;
    days[3] = Resources.getResources().We;
    days[4] = Resources.getResources().Th;
    days[5] = Resources.getResources().Fr;
    days[6] = Resources.getResources().Sa;
    return days[day];
};

/** 
 * @function
 * @description Gets short month name from javascript date
 * @param date
 */
DateHelper.getShortMonth = function(date)
{
    var month = date.getMonth();
    var months = [];
    months[0] = Resources.getResources().Jan;
    months[1] = Resources.getResources().Feb;
    months[2] = Resources.getResources().Mar;
    months[3] = Resources.getResources().Apr;
    months[4] = Resources.getResources().May;
    months[5] = Resources.getResources().Jun;
    months[6] = Resources.getResources().Jul;
    months[7] = Resources.getResources().Aug;
    months[8] = Resources.getResources().Sep;
    months[9] = Resources.getResources().Oct;
    months[10] = Resources.getResources().Nov;
    months[11] = Resources.getResources().Dec;
    
    return months[month];
};

/** 
 * @function
 * @description Gets Date js object from date (with 00:00:00 time)
 * @param date
 */
DateHelper.getDateFrom = function (date) {
	var result = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0);
	
	return result;
};

/** 
 * @function
 * @description Gets Date js object from date (with 23:59:59 time)
 * @param date
 */
DateHelper.getDateTill = function (date) {
	var result = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 23, 59, 59);
	
	return result;
};

/** 
 * @function
 * @description Sets date range by from and till values
 * @param dateFrom - from date value
 * @param dateTill - till date value
 */
DateHelper.DateRange = function (dateFrom, dateTill) {
	if (dateFrom && dateTill) {
		this.dateFrom = DateHelper.getDateFrom(dateFrom);
		this.dateTill = DateHelper.getDateTill(dateTill);
	} else if (dateFrom && !dateTill) {
		this.dateFrom = DateHelper.getDateFrom(dateFrom);
		this.dateTill = DateHelper.getDateTill(dateFrom);
	}
};

/** 
 * @function
 * @description Sets backgound image of scene to transparent image
 */
Helpers.setBackgroundOpacity = function(){
    $(".background").css({"backgroundImage":"url(images/player/background-shader.png)"});
    $(".categoriesListBG").addClass("styleWithOpacity");
};

/** 
 * @function
 * @description Removes transparent backgound image
 */
Helpers.removeBackgroundOpacity = function () {
    $(".background").css({"backgroundImage":"url(images/SMC_main_bg.png)"});
    $(".categoriesListBG").removeClass("styleWithOpacity");
};

/** 
 * @function
 * @description Checks client settings for specified service
 * @param {string} service - service name (LiveTv for ex.)
 * @param {string} status - status to check(NA for ex.)
 * @param {boolean} condition - must comply with status or should not.
 */
Helpers.checkServiceStatus = function (service, status, condition) {
    //service = service.toLowerCase();
	if (typeof(service) == "string") {
		service = JsonServices.ContentType[service];
	}
	if (typeof(status) == "string") {
		status = JsonServices.Status[status];
	}
    for (var i = 0; i < AppContext.ClientSettings.services.length; i++) {
        var oneService = AppContext.ClientSettings.services[i];
        if (condition) {
            if (oneService.serviceContentType == service && oneService.serviceStatus == status) {
				return true;
            }
        } else {
            if (oneService.serviceContentType == service && oneService.serviceStatus != status) {
				return true;
            }
        }
    }
    return false;
};

/** 
 * @function
 * @description Checks client settings for specified scene
 * @param {string} scene - scene name
 * @param {string} checkStatus - status to check(NA for ex.)
 * @param {boolean} condition - must comply with status or should not.
 */
Helpers.checkScene = function (scene, checkStatus, condition) {
    scene = scene.toLowerCase();
    if (scene == "livetv") {
        return Helpers.checkServiceStatus("LiveTV", checkStatus, condition);
    } else if ((scene.indexOf("archtv") != -1)) {
        return Helpers.checkServiceStatus("DVR", checkStatus, condition);
    } else if ((scene.indexOf("movies") != -1) || scene == "series") {
        return Helpers.checkServiceStatus("VOD", checkStatus, condition);
    } else if (scene.indexOf("archplus") > -1 || scene.indexOf("programepisodes") > -1) {
		return Helpers.checkServiceStatus("ArcPlus", checkStatus, condition);
	} else if (scene == "radio") {
        return Helpers.checkServiceStatus("Radio", checkStatus, condition);
	} else if (scene.indexOf("favorites") > -1) {
		return Helpers.checkServiceStatus("DVR", checkStatus, condition)
			|| Helpers.checkServiceStatus("VOD", checkStatus, condition)
			|| Helpers.checkServiceStatus("ArcPlus", checkStatus, condition);
    } else {
        return false;
    }
};

/** 
 * @function
 * @description Checks status of content type in settings
 * @param {string} contentType - name of content type.
 */
Helpers.checkStatus = function (contentType) {
    if (Helpers.checkServiceStatus(contentType, "Enabled", true)) {
        return ServiceStatuses.enabled;
    } else if (Helpers.checkServiceStatus(contentType, "PreviewAvailable", true)) {
        return ServiceStatuses.previewAvailable;
    } else if (Helpers.checkServiceStatus(contentType, "Available", true)) {
        return ServiceStatuses.available;
    } else {
        return ServiceStatuses.na;
    }
};

/** 
 * @function
 * @description Checks all the services whether are enabled.
 * @return {boolean} true if all services are enabled
 */
Helpers.checkAllServices = function () {
	var services = ["LiveTV", "DVR", "VOD", "ArcPlus", "Radio"];
	for (var i = 0; i < services.length; i++) {
		if (Helpers.checkServiceStatus(services[i], "Enabled", true)) {
			return true;
		}
	}
	return false;
};

/** 
 * @function
 * @description Converts int time to time in format HH:MM:SS
 * @param {number} time - time in numeric format
 */
Helpers.intTimeToString = function (time) {
    if (time < 0)
        return "0:00:00";
    
    var timeHour = Math.floor(time/3600000);
    var timeMinute = Math.floor((time%3600000)/60000);
    var timeSecond = Math.floor((time%60000)/1000);
    var timeHTML = timeHour + ":";
    if(timeMinute == 0) {
        timeHTML += "00:";
    } else if(timeMinute <10) {
        timeHTML += "0" + timeMinute + ":";
    } else {
        timeHTML += timeMinute + ":";
	}
            
    if (timeSecond == 0) {
        timeHTML += "00";
    } else if(timeSecond <10) {
        timeHTML += "0" + timeSecond;
    } else {
        timeHTML +=  timeSecond;
	}
    return timeHTML;
};

/** 
 * @function
 * @description [NOW IS EMPTY] Convert date to milliseconds
 * @param date - date to convert.
 */
Helpers.dateToMs = function (date) {
	
};

/** 
 * @function
 * @description Gets DUID of device
 */
Helpers.getDUID = function(){
    Logger.write("Useragent: " + navigator.userAgent, "Helpers", true);
    var DUID = deviceapis.tv.info.getDeviceID();
    return  DUID;
};

/** 
 * @function
 * @description Check device vesion, 2011 or not.
 * @return {boolean} true if model of the device is 2011.
 */
Helpers.is2011Model = function () {
	var rx = /.*Maple 6.*/i;
	var result = rx.test(navigator.userAgent);
	Logger.write("Is 2011 Model: " + result, "Helpers", true);
	return result; 
};

/** 
 * @function
 * @description Loads xml
 * @param url - url of the request.
 * @param cb - callback occurs on success.
 * @param errorCb - callback occurs on error.
 */
Helpers.loadXML = function(url, cb, errorCb){
    $.ajax({
		type: "GET",
		url: url,
		dataType: "xml",
		error: errorCb || function(){},
		timeout: Options.timeout,
		success: cb || function(){}
	});
};

/** 
 * @function
 * @description Return default or user defined buffers
 */
Helpers.loadBuffers = function () {
	Logger.write("Loading current buffers", "Settings", true);
	var fs = new FileSystem();
	
	if (fs.isValidCommonPath(curWidget.id) !== 1) {
		Logger.write("Creating path", "Settings", true);
		fs.createCommonDir(curWidget.id);
	}
	
	var file = fs.openCommonFile(curWidget.id + "/settings_" + AppContext.user.login + ".xml", "r");
	if (!file) {
		file = fs.openFile("defaultSettings.xml", "r");
	}
	var content = file.readAll();
	Logger.write("File Content: " + content, "Settings", true);
	fs.closeCommonFile(file);
	
	var parser = new DOMParser();
	var doc = parser.parseFromString(content, 'text/xml');
	
	var settings = {};
	$(doc).find("settings").each(function () {
		settings.totalBuffer = $(this).find("totalBuffer").text();
		settings.initialBuffer = $(this).find("initialBuffer").text();
		settings.pendingBuffer = $(this).find("pendingBuffer").text();
	});
	
	return settings;
};

/** 
 * @function
 * @description Save user defined buffer
 */
Helpers.saveBuffers = function (settings) {
	if (!settings || !settings.totalBuffer || !settings.initialBuffer || !settings.pendingBuffer) {
		throw new Error("Invalid argument");
	}
	
	var fs = new FileSystem();
		
	if (fs.isValidCommonPath(curWidget.id) !== 1) {
		fs.createCommonDir(curWidget.id);
	}
	
	var file = fs.openCommonFile(curWidget.id + "/settings_" + AppContext.user.login + ".xml", "w");
	if (file) {
		var content = '<?xml version="1.0" encoding="UTF-8"?><settings>';
		content += '<totalBuffer>' + settings.totalBuffer + '</totalBuffer>';
		content += '<initialBuffer>' + settings.initialBuffer + '</initialBuffer>';
		content += '<pendingBuffer>' + settings.pendingBuffer + '</pendingBuffer>';
		content += '</settings>';
		
		var writed = file.writeAll(content);
		fs.closeCommonFile(file);
		if (writed) {
			return true;
		}
	}	
	return false;
};

/** 
 * @function
 * @description Check genre on adult status.
 * @return {boolean} return true if status id= 10, 137 or 138.
 */
Helpers.isAdultMovieGenre = function (id) {
	if (id == 10 || id == 137 || id == 138) {
		return true;
	}
	
	return false;
};

/** 
 * @function
 * @description Add time stamp to object.
 * @param obj - object to which append time stamp.
 * @param ttl - time to live (in minutes).
 */
Helpers.addTimeStamp = function (obj, ttl) {
	ttl = ttl || 60;
	obj.timeStamp = new Date();
	obj.ttl = ttl;
	obj.isExpired = function () {
		var age = (new Date() - this.timeStamp) / 60000;
		if (age > ttl) {
			return true;
		}
		
		return false;
	};
};

/** 
 * @function
 * @description Occurs when global key is pressed.
 * @param keyCode - code of the pressed key.
 */
Helpers.handleGlobalKeys = function (keyCode) {
	Logger.write("Handling global key", "Helpers");
	for (var key in sf.key) {
		if (sf.key[key] == keyCode) {
			Logger.write("The key is '" + key + "'", "Helpers", true);
		}
	}
	switch (keyCode) {
		case sf.key.FF:
		case sf.key.CH_UP:
			if (ScenePlayer.isPlaying) {
				ScenePlayer.handleChUp();
			}
			return true;
			break;
		case sf.key.REW:
		case sf.key.CH_DOWN:
			if (ScenePlayer.isPlaying) {
				ScenePlayer.handleChDown();
			}
			return true;
			break;
	}
	
	Logger.write("Global key wasn't handled", "Helpers");
	return false;
};

/** 
 * @function
 * @description Provides converting time to UTC format.
 * @param time - time to convert
 * @return time in UTC format without GMT symbols.
 */
Helpers.getUtcTime = function (time) {
	return new Date(time.getUTCFullYear(), time.getUTCMonth(), time.getUTCDate(), time.getUTCHours(), time.getUTCMinutes(), time.getUTCSeconds(),time.getUTCMilliseconds());
};
