/**
 * @class Class that describes network plugin entity and provides work with it.
 */
Network = {};

/**
 * @function
 * @description Initializes network plugin
 */
Network.init = function() {
    networkPlugin = document.getElementById("pluginObjectNetwork");
    networkPlugin.CreatePlugin();
    
    /*var cb = function (networks) {
    	Network.info = networks[1];
    	for (var key in Network.info) {
    		Logger.write("Network.info[" + key + "] = " + Network.info[key], "Network", true);
    	}
    };
    
    deviceapis.network.getAvailableNetworks(cb);*/
};

/**
 * @class [ENUM]Types of device's network interfaces
 */
Network.interfacesTypes = {
		/**
		 * [READONLY]
		 * @field
		 * @description wireless interface
		 * @default 0
		 */
		wireless:0, 
		/**
		 * [READONLY]
		 * @field
		 * @description wired interface
		 * @default 1
		 */
		wired:1, 
		/**
		 * [READONLY]
		 * @field
		 * @description no connection.
		 * @default -1
		 */
		noConnection:-1
		};

/**
 * @class [ENUM] States of network connection
 */
Network.states = {
		/**
		 * [READONLY]
		 * @field
		 * @description state OK
		 * @default 1
		 */
		ok:1, 
		/**
		 * [READONLY]
		 * @field
		 * @description state FAIL
		 * @default 0
		 */
		failure:0, 
		/**
		 * [READONLY]
		 * @field
		 * @description state ERROR
		 * @default -1
		 */
		error:-1
		};

/**
 * @class [ENUM] Types of network check
 */
Network.checkTypes = {
		/**
		 * [READONLY]
		 * @field
		 * @description physical connection check
		 * @default 0
		 */
		physicalConnection:0, 
		/**
		 * [READONLY]
		 * @field
		 * @description gateway check
		 * @default 1
		 */
		gateway:1,
		/**
		 * [READONLY]
		 * @field
		 * @description http check
		 * @default 2
		 */
		http:2, 
		/**
		 * [READONLY]
		 * @field
		 * @description dns check
		 * @default 3
		 */
		dns:3
		};

/**
 * @function
 * @description Checks network state by level
 * @param {number} iType - Type of device's network interface ({@link Network.interfacesTypes})
 * @param {number} checkType - checking type ({@link Network.checkTypes})
 * @returns {string} state
 */
Network.checkByType = function(iType, checkType){
    var state = "";
    switch(checkType)
    {
        case Network.checkTypes.dns:
            state = networkPlugin.CheckDNS(iType);
            break;
        case Network.checkTypes.gateway:
            state = networkPlugin.CheckGateway(iType);
            break;
        case Network.checkTypes.physicalConnection:
            state = networkPlugin.CheckPhysicalConnection(iType);
            break;
        case Network.checkTypes.http:
            state = networkPlugin.CheckHTTP(iType);
            break;
    }    
    
    Logger.write("[Network] iType=" + iType + " | checkType=" + checkType + " | state=" + state, "Network");
    return state;
};

/**
 * @function
 * @description Checks network state
 */
Network.check = function(){
        Network.activeType = networkPlugin.GetActiveType();
        
        for(key in Network.checkTypes)
        {
            var state = Network.checkByType(Network.activeType, Network.checkTypes[key]);
            if (state != Network.states.ok)
            {
                Network.handleError(Network.checkTypes[key], state);
                break;
            }
        }
        
     Logger.write("[Network] Check completed", "Network");
};

/**
 * @event
 * @description Event occurs when error is handled.
 * @param checkType - {number} checkType - checking type ({@link Network.checkTypes})
 * @param state - network connection state ({@link Network.states})
 */
Network.handleError = function(checkType, state){
    var errorMessage = "";
    switch(Network.activeType)
    {
        case Network.interfacesTypes.wired:
            errorMessage += "Wired Connection. ";
            break;
        case Network.interfacesTypes.wireless:
            errorMessage += "Wireless Connection. ";
            break;
        case Network.interfacesTypes.noConnection:
            return;
            break;
    }
    switch(checkType)
    {
        case Network.checkTypes.dns:
            errorMessage += "Check DNS ";
            break;
        case Network.checkTypes.gateway:
            errorMessage += "Check gateway ";
            break;
        case Network.checkTypes.physicalConnection:
            errorMessage += "Check physical connection ";
            break;
        case Network.checkTypes.http:
            errorMessage += "Check HTTP ";
            break;
    }        
    switch(state)
    {
        case Network.states.failure:
            errorMessage += "Failure. ";
            break;
        case Network.states.error:
            errorMessage += "Error. ";
            break;
    }
    
    if  (ScenePlayer.isPlaying == true)
    {
        ScenePlayer.stopAndReturn();
    }
    ErrorHandler.HandleError(errorMessage, AppContext.CurrentScene);
};