/**
 * @class Class describes application resources. 
 */
var Resources = {
		/**
		 * @field
		 * @description data of the resource
		 * @default null
		 */
    resourcesData: null,
    /**
	 * @field
	 * @description current language.
	 * @default null
	 */
    currentLang: null,
    /**
	 * @field
	 * @description url to resource file.
	 * @default "Resources/*.js"
	 */
    resourceUrl: "Resources/*.js"
};

/**
 * @function
 * @description Provides initialize of the resources
 */
Resources.initResources = function()
{
    Logger.write("Init resources", "Resources");
    getResources(AppContext.ClientSettings.Language.cultureInfo);
};

/**
 * @function
 * @description Gets resources for selected language
 * @param {string} lang - current language name.
 */
Resources.getResources = function(lang)
{
    if (arguments.length == 0)
    {
        if (this.currentLang == null)
        {
            this.currentLang = AppContext.ClientSettings.Language.cultureInfo;
        }
        lang = this.currentLang;
    }
    
    //Logger.write("getting resources", "Resources");
    if (this.resourcesData == null || this.currentLang != lang)
    {
        var url = this.resourceUrl.replace(/\*/, lang);
        //Logger.write("URL:"+url, "Resources");
        this.resourcesData = $.parseJSON($.ajax(
        {
            type: "GET",
            url: url,
            dataType: "text",
            async: false,
        }).responseText);
        //Logger.write("result: "+this.resourcesData, "Resources");
        this.currentLang = lang;
    }
    
    return this.resourcesData;
};